@@ -1,11 +1,63 @@
 from __future__ import annotations
+import kdsl.core.v1_converters
+import kdsl.apiregistration.v1_converters
 import kdsl.core.v1
 import attr
 import kdsl.apiregistration.v1
-import kdsl.core.v1_converters
-import kdsl.apiregistration.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
+
+
+@attr.s(kw_only=True)
+class APIService(K8sResource):
+    apiVersion: ClassVar[str] = "apiregistration.k8s.io/v1"
+    kind: ClassVar[str] = "APIService"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    spec: Union[None, OmitEnum, kdsl.apiregistration.v1.APIServiceSpec] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.apiregistration.v1_converters.optional_converter_APIServiceSpec,
+        default=OMIT,
+    )
+    status: Union[None, OmitEnum, kdsl.apiregistration.v1.APIServiceStatus] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.apiregistration.v1_converters.optional_converter_APIServiceStatus,
+        default=OMIT,
+    )
+
+
+@attr.s(kw_only=True)
+class APIServiceConditionItem(K8sObject):
+    status: str = attr.ib(metadata={"yaml_name": "status"})
+    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
+    )
+    message: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "message"}, default=OMIT
+    )
+    reason: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "reason"}, default=OMIT
+    )
+
+
+class APIServiceConditionItemOptionalTypedDict(TypedDict, total=(False)):
+    lastTransitionTime: str
+    message: str
+    reason: str
+
+
+class APIServiceConditionItemTypedDict(
+    APIServiceConditionItemOptionalTypedDict, total=(True)
+):
+    status: str
+
+
+APIServiceConditionItemUnion = Union[
+    APIServiceConditionItem, APIServiceConditionItemTypedDict
+]
 
 
 @attr.s(kw_only=True)
@@ -48,58 +100,6 @@ class APIServiceStatusTypedDict(TypedDict, total=(False)):
 APIServiceStatusUnion = Union[APIServiceStatus, APIServiceStatusTypedDict]
 
 
-@attr.s(kw_only=True)
-class APIServiceConditionItem(K8sObject):
-    status: str = attr.ib(metadata={"yaml_name": "status"})
-    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
-    )
-    message: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "message"}, default=OMIT
-    )
-    reason: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "reason"}, default=OMIT
-    )
-
-
-class APIServiceConditionItemOptionalTypedDict(TypedDict, total=(False)):
-    lastTransitionTime: str
-    message: str
-    reason: str
-
-
-class APIServiceConditionItemTypedDict(
-    APIServiceConditionItemOptionalTypedDict, total=(True)
-):
-    status: str
-
-
-APIServiceConditionItemUnion = Union[
-    APIServiceConditionItem, APIServiceConditionItemTypedDict
-]
-
-
-@attr.s(kw_only=True)
-class APIService(K8sResource):
-    apiVersion: ClassVar[str] = "apiregistration.k8s.io/v1"
-    kind: ClassVar[str] = "APIService"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[None, OmitEnum, kdsl.apiregistration.v1.APIServiceSpec] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.apiregistration.v1_converters.optional_converter_APIServiceSpec,
-        default=OMIT,
-    )
-    status: Union[None, OmitEnum, kdsl.apiregistration.v1.APIServiceStatus] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.apiregistration.v1_converters.optional_converter_APIServiceStatus,
-        default=OMIT,
-    )
-
-
 @attr.s(kw_only=True)
 class APIServiceSpec(K8sObject):
     groupPriorityMinimum: int = attr.ib(metadata={"yaml_name": "groupPriorityMinimum"})
