@@ -1,11 +1,34 @@
 from __future__ import annotations
-import attr
-import kdsl.core.v1
-import kdsl.apiregistration.v1beta1_converters
 import kdsl.core.v1_converters
+import kdsl.core.v1
+import attr
+import kdsl.apiregistration.v1beta1_converters
 import kdsl.apiregistration.v1beta1
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
+
+
+@attr.s(kw_only=True)
+class APIService(K8sResource):
+    apiVersion: ClassVar[str] = "apiregistration.k8s.io/v1beta1"
+    kind: ClassVar[str] = "APIService"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    spec: Union[None, OmitEnum, kdsl.apiregistration.v1beta1.APIServiceSpec] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.apiregistration.v1beta1_converters.optional_converter_APIServiceSpec,
+        default=OMIT,
+    )
+    status: Union[
+        None, OmitEnum, kdsl.apiregistration.v1beta1.APIServiceStatus
+    ] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.apiregistration.v1beta1_converters.optional_converter_APIServiceStatus,
+        default=OMIT,
+    )
 
 
 @attr.s(kw_only=True)
@@ -40,28 +63,25 @@ APIServiceConditionItemUnion = Union[
 
 
 @attr.s(kw_only=True)
-class APIService(K8sResource):
-    apiVersion: ClassVar[str] = "apiregistration.k8s.io/v1beta1"
-    kind: ClassVar[str] = "APIService"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[None, OmitEnum, kdsl.apiregistration.v1beta1.APIServiceSpec] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.apiregistration.v1beta1_converters.optional_converter_APIServiceSpec,
-        default=OMIT,
-    )
-    status: Union[
-        None, OmitEnum, kdsl.apiregistration.v1beta1.APIServiceStatus
+class APIServiceStatus(K8sObject):
+    conditions: Union[
+        None,
+        OmitEnum,
+        Mapping[str, kdsl.apiregistration.v1beta1.APIServiceConditionItem],
     ] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.apiregistration.v1beta1_converters.optional_converter_APIServiceStatus,
+        metadata={"yaml_name": "conditions", "mlist_key": "type"},
+        converter=kdsl.apiregistration.v1beta1_converters.optional_mlist_converter_APIServiceConditionItem,
         default=OMIT,
     )
 
 
+class APIServiceStatusTypedDict(TypedDict, total=(False)):
+    conditions: Mapping[str, kdsl.apiregistration.v1beta1.APIServiceConditionItem]
+
+
+APIServiceStatusUnion = Union[APIServiceStatus, APIServiceStatusTypedDict]
+
+
 @attr.s(kw_only=True)
 class APIServiceSpec(K8sObject):
     groupPriorityMinimum: int = attr.ib(metadata={"yaml_name": "groupPriorityMinimum"})
@@ -100,26 +120,6 @@ class APIServiceSpecTypedDict(APIServiceSpecOptionalTypedDict, total=(True)):
 APIServiceSpecUnion = Union[APIServiceSpec, APIServiceSpecTypedDict]
 
 
-@attr.s(kw_only=True)
-class APIServiceStatus(K8sObject):
-    conditions: Union[
-        None,
-        OmitEnum,
-        Mapping[str, kdsl.apiregistration.v1beta1.APIServiceConditionItem],
-    ] = attr.ib(
-        metadata={"yaml_name": "conditions", "mlist_key": "type"},
-        converter=kdsl.apiregistration.v1beta1_converters.optional_mlist_converter_APIServiceConditionItem,
-        default=OMIT,
-    )
-
-
-class APIServiceStatusTypedDict(TypedDict, total=(False)):
-    conditions: Mapping[str, kdsl.apiregistration.v1beta1.APIServiceConditionItem]
-
-
-APIServiceStatusUnion = Union[APIServiceStatus, APIServiceStatusTypedDict]
-
-
 @attr.s(kw_only=True)
 class ServiceReference(K8sObject):
     name: Union[None, OmitEnum, str] = attr.ib(
