@@ -1,99 +1,32 @@
 from __future__ import annotations
+import kdsl.core.v1_converters
 import kdsl.core.v1
 import attr
 import kdsl.apps.v1_converters
 import kdsl.apps.v1
-import kdsl.core.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
-class StatefulSetSpec(K8sObject):
-    selector: kdsl.core.v1.LabelSelector = attr.ib(
-        metadata={"yaml_name": "selector"},
-        converter=kdsl.core.v1_converters.required_converter_LabelSelector,
-    )
-    serviceName: str = attr.ib(metadata={"yaml_name": "serviceName"})
-    template: kdsl.core.v1.PodTemplateSpec = attr.ib(
-        metadata={"yaml_name": "template"},
-        converter=kdsl.core.v1_converters.required_converter_PodTemplateSpec,
-    )
-    podManagementPolicy: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "podManagementPolicy"}, default=OMIT
-    )
-    replicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "replicas"}, default=OMIT
-    )
-    revisionHistoryLimit: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "revisionHistoryLimit"}, default=OMIT
-    )
-    updateStrategy: Union[
-        None, OmitEnum, kdsl.apps.v1.StatefulSetUpdateStrategy
-    ] = attr.ib(
-        metadata={"yaml_name": "updateStrategy"},
-        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetUpdateStrategy,
+class StatefulSet(K8sResource):
+    apiVersion: ClassVar[str] = "apps/v1"
+    kind: ClassVar[str] = "StatefulSet"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
         default=OMIT,
     )
-    volumeClaimTemplates: Union[
-        None, OmitEnum, Sequence[kdsl.core.v1.EmbeddedPersistentVolumeClaim]
-    ] = attr.ib(
-        metadata={"yaml_name": "volumeClaimTemplates"},
-        converter=kdsl.core.v1_converters.optional_list_converter_EmbeddedPersistentVolumeClaim,
+    spec: Union[None, OmitEnum, kdsl.apps.v1.StatefulSetSpec] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetSpec,
         default=OMIT,
     )
-
-
-class StatefulSetSpecOptionalTypedDict(TypedDict, total=(False)):
-    podManagementPolicy: str
-    replicas: int
-    revisionHistoryLimit: int
-    updateStrategy: kdsl.apps.v1.StatefulSetUpdateStrategy
-    volumeClaimTemplates: Sequence[kdsl.core.v1.EmbeddedPersistentVolumeClaim]
-
-
-class StatefulSetSpecTypedDict(StatefulSetSpecOptionalTypedDict, total=(True)):
-    selector: kdsl.core.v1.LabelSelector
-    serviceName: str
-    template: kdsl.core.v1.PodTemplateSpec
-
-
-StatefulSetSpecUnion = Union[StatefulSetSpec, StatefulSetSpecTypedDict]
-
-
-@attr.s(kw_only=True)
-class DeploymentConditionItem(K8sObject):
-    status: str = attr.ib(metadata={"yaml_name": "status"})
-    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
+    status: Union[None, OmitEnum, kdsl.apps.v1.StatefulSetStatus] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetStatus,
+        default=OMIT,
     )
-    lastUpdateTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastUpdateTime"}, default=OMIT
-    )
-    message: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "message"}, default=OMIT
-    )
-    reason: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "reason"}, default=OMIT
-    )
-
-
-class DeploymentConditionItemOptionalTypedDict(TypedDict, total=(False)):
-    lastTransitionTime: str
-    lastUpdateTime: str
-    message: str
-    reason: str
-
-
-class DeploymentConditionItemTypedDict(
-    DeploymentConditionItemOptionalTypedDict, total=(True)
-):
-    status: str
-
-
-DeploymentConditionItemUnion = Union[
-    DeploymentConditionItem, DeploymentConditionItemTypedDict
-]
 
 
 @attr.s(kw_only=True)
@@ -165,47 +98,118 @@ class ControllerRevision(K8sResource):
 
 
 @attr.s(kw_only=True)
-class StatefulSet(K8sResource):
+class DeploymentStrategy(K8sObject):
+    rollingUpdate: Union[
+        None, OmitEnum, kdsl.apps.v1.RollingUpdateDeployment
+    ] = attr.ib(
+        metadata={"yaml_name": "rollingUpdate"},
+        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateDeployment,
+        default=OMIT,
+    )
+    type: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "type"}, default=OMIT
+    )
+
+
+class DeploymentStrategyTypedDict(TypedDict, total=(False)):
+    rollingUpdate: kdsl.apps.v1.RollingUpdateDeployment
+    type: str
+
+
+DeploymentStrategyUnion = Union[DeploymentStrategy, DeploymentStrategyTypedDict]
+
+
+@attr.s(kw_only=True)
+class ReplicaSet(K8sResource):
     apiVersion: ClassVar[str] = "apps/v1"
-    kind: ClassVar[str] = "StatefulSet"
+    kind: ClassVar[str] = "ReplicaSet"
     metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
         metadata={"yaml_name": "metadata"},
         converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
         default=OMIT,
     )
-    spec: Union[None, OmitEnum, kdsl.apps.v1.StatefulSetSpec] = attr.ib(
+    spec: Union[None, OmitEnum, kdsl.apps.v1.ReplicaSetSpec] = attr.ib(
         metadata={"yaml_name": "spec"},
-        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetSpec,
+        converter=kdsl.apps.v1_converters.optional_converter_ReplicaSetSpec,
         default=OMIT,
     )
-    status: Union[None, OmitEnum, kdsl.apps.v1.StatefulSetStatus] = attr.ib(
+    status: Union[None, OmitEnum, kdsl.apps.v1.ReplicaSetStatus] = attr.ib(
         metadata={"yaml_name": "status"},
-        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetStatus,
+        converter=kdsl.apps.v1_converters.optional_converter_ReplicaSetStatus,
         default=OMIT,
     )
 
 
 @attr.s(kw_only=True)
-class DaemonSet(K8sResource):
-    apiVersion: ClassVar[str] = "apps/v1"
-    kind: ClassVar[str] = "DaemonSet"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+class DeploymentStatus(K8sObject):
+    availableReplicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "availableReplicas"}, default=OMIT
+    )
+    collisionCount: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "collisionCount"}, default=OMIT
+    )
+    conditions: Union[
+        None, OmitEnum, Mapping[str, kdsl.apps.v1.DeploymentConditionItem]
+    ] = attr.ib(
+        metadata={"yaml_name": "conditions", "mlist_key": "type"},
+        converter=kdsl.apps.v1_converters.optional_mlist_converter_DeploymentConditionItem,
         default=OMIT,
     )
-    spec: Union[None, OmitEnum, kdsl.apps.v1.DaemonSetSpec] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.apps.v1_converters.optional_converter_DaemonSetSpec,
+    observedGeneration: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "observedGeneration"}, default=OMIT
+    )
+    readyReplicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "readyReplicas"}, default=OMIT
+    )
+    replicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "replicas"}, default=OMIT
+    )
+    unavailableReplicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "unavailableReplicas"}, default=OMIT
+    )
+    updatedReplicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "updatedReplicas"}, default=OMIT
+    )
+
+
+class DeploymentStatusTypedDict(TypedDict, total=(False)):
+    availableReplicas: int
+    collisionCount: int
+    conditions: Mapping[str, kdsl.apps.v1.DeploymentConditionItem]
+    observedGeneration: int
+    readyReplicas: int
+    replicas: int
+    unavailableReplicas: int
+    updatedReplicas: int
+
+
+DeploymentStatusUnion = Union[DeploymentStatus, DeploymentStatusTypedDict]
+
+
+@attr.s(kw_only=True)
+class StatefulSetUpdateStrategy(K8sObject):
+    rollingUpdate: Union[
+        None, OmitEnum, kdsl.apps.v1.RollingUpdateStatefulSetStrategy
+    ] = attr.ib(
+        metadata={"yaml_name": "rollingUpdate"},
+        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateStatefulSetStrategy,
         default=OMIT,
     )
-    status: Union[None, OmitEnum, kdsl.apps.v1.DaemonSetStatus] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.apps.v1_converters.optional_converter_DaemonSetStatus,
-        default=OMIT,
+    type: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "type"}, default=OMIT
     )
 
 
+class StatefulSetUpdateStrategyTypedDict(TypedDict, total=(False)):
+    rollingUpdate: kdsl.apps.v1.RollingUpdateStatefulSetStrategy
+    type: str
+
+
+StatefulSetUpdateStrategyUnion = Union[
+    StatefulSetUpdateStrategy, StatefulSetUpdateStrategyTypedDict
+]
+
+
 @attr.s(kw_only=True)
 class DaemonSetSpec(K8sObject):
     selector: kdsl.core.v1.LabelSelector = attr.ib(
@@ -245,127 +249,6 @@ class DaemonSetSpecTypedDict(DaemonSetSpecOptionalTypedDict, total=(True)):
 DaemonSetSpecUnion = Union[DaemonSetSpec, DaemonSetSpecTypedDict]
 
 
-@attr.s(kw_only=True)
-class DaemonSetUpdateStrategy(K8sObject):
-    rollingUpdate: Union[None, OmitEnum, kdsl.apps.v1.RollingUpdateDaemonSet] = attr.ib(
-        metadata={"yaml_name": "rollingUpdate"},
-        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateDaemonSet,
-        default=OMIT,
-    )
-    type: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "type"}, default=OMIT
-    )
-
-
-class DaemonSetUpdateStrategyTypedDict(TypedDict, total=(False)):
-    rollingUpdate: kdsl.apps.v1.RollingUpdateDaemonSet
-    type: str
-
-
-DaemonSetUpdateStrategyUnion = Union[
-    DaemonSetUpdateStrategy, DaemonSetUpdateStrategyTypedDict
-]
-
-
-@attr.s(kw_only=True)
-class RollingUpdateStatefulSetStrategy(K8sObject):
-    partition: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "partition"}, default=OMIT
-    )
-
-
-class RollingUpdateStatefulSetStrategyTypedDict(TypedDict, total=(False)):
-    partition: int
-
-
-RollingUpdateStatefulSetStrategyUnion = Union[
-    RollingUpdateStatefulSetStrategy, RollingUpdateStatefulSetStrategyTypedDict
-]
-
-
-@attr.s(kw_only=True)
-class StatefulSetConditionItem(K8sObject):
-    status: str = attr.ib(metadata={"yaml_name": "status"})
-    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
-    )
-    message: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "message"}, default=OMIT
-    )
-    reason: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "reason"}, default=OMIT
-    )
-
-
-class StatefulSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
-    lastTransitionTime: str
-    message: str
-    reason: str
-
-
-class StatefulSetConditionItemTypedDict(
-    StatefulSetConditionItemOptionalTypedDict, total=(True)
-):
-    status: str
-
-
-StatefulSetConditionItemUnion = Union[
-    StatefulSetConditionItem, StatefulSetConditionItemTypedDict
-]
-
-
-@attr.s(kw_only=True)
-class Deployment(K8sResource):
-    apiVersion: ClassVar[str] = "apps/v1"
-    kind: ClassVar[str] = "Deployment"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[None, OmitEnum, kdsl.apps.v1.DeploymentSpec] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.apps.v1_converters.optional_converter_DeploymentSpec,
-        default=OMIT,
-    )
-    status: Union[None, OmitEnum, kdsl.apps.v1.DeploymentStatus] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.apps.v1_converters.optional_converter_DeploymentStatus,
-        default=OMIT,
-    )
-
-
-@attr.s(kw_only=True)
-class ReplicaSetConditionItem(K8sObject):
-    status: str = attr.ib(metadata={"yaml_name": "status"})
-    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
-    )
-    message: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "message"}, default=OMIT
-    )
-    reason: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "reason"}, default=OMIT
-    )
-
-
-class ReplicaSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
-    lastTransitionTime: str
-    message: str
-    reason: str
-
-
-class ReplicaSetConditionItemTypedDict(
-    ReplicaSetConditionItemOptionalTypedDict, total=(True)
-):
-    status: str
-
-
-ReplicaSetConditionItemUnion = Union[
-    ReplicaSetConditionItem, ReplicaSetConditionItemTypedDict
-]
-
-
 @attr.s(kw_only=True)
 class StatefulSetStatus(K8sObject):
     replicas: int = attr.ib(metadata={"yaml_name": "replicas"})
@@ -417,6 +300,53 @@ class StatefulSetStatusTypedDict(StatefulSetStatusOptionalTypedDict, total=(True
 StatefulSetStatusUnion = Union[StatefulSetStatus, StatefulSetStatusTypedDict]
 
 
+@attr.s(kw_only=True)
+class StatefulSetConditionItem(K8sObject):
+    status: str = attr.ib(metadata={"yaml_name": "status"})
+    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
+    )
+    message: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "message"}, default=OMIT
+    )
+    reason: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "reason"}, default=OMIT
+    )
+
+
+class StatefulSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
+    lastTransitionTime: str
+    message: str
+    reason: str
+
+
+class StatefulSetConditionItemTypedDict(
+    StatefulSetConditionItemOptionalTypedDict, total=(True)
+):
+    status: str
+
+
+StatefulSetConditionItemUnion = Union[
+    StatefulSetConditionItem, StatefulSetConditionItemTypedDict
+]
+
+
+@attr.s(kw_only=True)
+class RollingUpdateStatefulSetStrategy(K8sObject):
+    partition: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "partition"}, default=OMIT
+    )
+
+
+class RollingUpdateStatefulSetStrategyTypedDict(TypedDict, total=(False)):
+    partition: int
+
+
+RollingUpdateStatefulSetStrategyUnion = Union[
+    RollingUpdateStatefulSetStrategy, RollingUpdateStatefulSetStrategyTypedDict
+]
+
+
 @attr.s(kw_only=True)
 class RollingUpdateDeployment(K8sObject):
     maxSurge: Union[None, OmitEnum, Union[int, str]] = attr.ib(
@@ -438,39 +368,60 @@ RollingUpdateDeploymentUnion = Union[
 
 
 @attr.s(kw_only=True)
-class ReplicaSetSpec(K8sObject):
+class StatefulSetSpec(K8sObject):
     selector: kdsl.core.v1.LabelSelector = attr.ib(
         metadata={"yaml_name": "selector"},
         converter=kdsl.core.v1_converters.required_converter_LabelSelector,
     )
-    minReadySeconds: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "minReadySeconds"}, default=OMIT
+    serviceName: str = attr.ib(metadata={"yaml_name": "serviceName"})
+    template: kdsl.core.v1.PodTemplateSpec = attr.ib(
+        metadata={"yaml_name": "template"},
+        converter=kdsl.core.v1_converters.required_converter_PodTemplateSpec,
+    )
+    podManagementPolicy: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "podManagementPolicy"}, default=OMIT
     )
     replicas: Union[None, OmitEnum, int] = attr.ib(
         metadata={"yaml_name": "replicas"}, default=OMIT
     )
-    template: Union[None, OmitEnum, kdsl.core.v1.PodTemplateSpec] = attr.ib(
-        metadata={"yaml_name": "template"},
-        converter=kdsl.core.v1_converters.optional_converter_PodTemplateSpec,
+    revisionHistoryLimit: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "revisionHistoryLimit"}, default=OMIT
+    )
+    updateStrategy: Union[
+        None, OmitEnum, kdsl.apps.v1.StatefulSetUpdateStrategy
+    ] = attr.ib(
+        metadata={"yaml_name": "updateStrategy"},
+        converter=kdsl.apps.v1_converters.optional_converter_StatefulSetUpdateStrategy,
+        default=OMIT,
+    )
+    volumeClaimTemplates: Union[
+        None, OmitEnum, Sequence[kdsl.core.v1.EmbeddedPersistentVolumeClaim]
+    ] = attr.ib(
+        metadata={"yaml_name": "volumeClaimTemplates"},
+        converter=kdsl.core.v1_converters.optional_list_converter_EmbeddedPersistentVolumeClaim,
         default=OMIT,
     )
 
 
-class ReplicaSetSpecOptionalTypedDict(TypedDict, total=(False)):
-    minReadySeconds: int
+class StatefulSetSpecOptionalTypedDict(TypedDict, total=(False)):
+    podManagementPolicy: str
     replicas: int
+    revisionHistoryLimit: int
+    updateStrategy: kdsl.apps.v1.StatefulSetUpdateStrategy
+    volumeClaimTemplates: Sequence[kdsl.core.v1.EmbeddedPersistentVolumeClaim]
+
+
+class StatefulSetSpecTypedDict(StatefulSetSpecOptionalTypedDict, total=(True)):
+    selector: kdsl.core.v1.LabelSelector
+    serviceName: str
     template: kdsl.core.v1.PodTemplateSpec
 
 
-class ReplicaSetSpecTypedDict(ReplicaSetSpecOptionalTypedDict, total=(True)):
-    selector: kdsl.core.v1.LabelSelector
-
-
-ReplicaSetSpecUnion = Union[ReplicaSetSpec, ReplicaSetSpecTypedDict]
+StatefulSetSpecUnion = Union[StatefulSetSpec, StatefulSetSpecTypedDict]
 
 
 @attr.s(kw_only=True)
-class DaemonSetConditionItem(K8sObject):
+class ReplicaSetConditionItem(K8sObject):
     status: str = attr.ib(metadata={"yaml_name": "status"})
     lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
         metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
@@ -483,124 +434,79 @@ class DaemonSetConditionItem(K8sObject):
     )
 
 
-class DaemonSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
+class ReplicaSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
     lastTransitionTime: str
     message: str
     reason: str
 
 
-class DaemonSetConditionItemTypedDict(
-    DaemonSetConditionItemOptionalTypedDict, total=(True)
+class ReplicaSetConditionItemTypedDict(
+    ReplicaSetConditionItemOptionalTypedDict, total=(True)
 ):
     status: str
 
 
-DaemonSetConditionItemUnion = Union[
-    DaemonSetConditionItem, DaemonSetConditionItemTypedDict
+ReplicaSetConditionItemUnion = Union[
+    ReplicaSetConditionItem, ReplicaSetConditionItemTypedDict
 ]
 
 
 @attr.s(kw_only=True)
-class DeploymentStrategy(K8sObject):
-    rollingUpdate: Union[
-        None, OmitEnum, kdsl.apps.v1.RollingUpdateDeployment
-    ] = attr.ib(
-        metadata={"yaml_name": "rollingUpdate"},
-        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateDeployment,
-        default=OMIT,
-    )
-    type: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "type"}, default=OMIT
-    )
-
-
-class DeploymentStrategyTypedDict(TypedDict, total=(False)):
-    rollingUpdate: kdsl.apps.v1.RollingUpdateDeployment
-    type: str
-
-
-DeploymentStrategyUnion = Union[DeploymentStrategy, DeploymentStrategyTypedDict]
-
-
-@attr.s(kw_only=True)
-class DeploymentStatus(K8sObject):
+class ReplicaSetStatus(K8sObject):
+    replicas: int = attr.ib(metadata={"yaml_name": "replicas"})
     availableReplicas: Union[None, OmitEnum, int] = attr.ib(
         metadata={"yaml_name": "availableReplicas"}, default=OMIT
     )
-    collisionCount: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "collisionCount"}, default=OMIT
-    )
     conditions: Union[
-        None, OmitEnum, Mapping[str, kdsl.apps.v1.DeploymentConditionItem]
+        None, OmitEnum, Mapping[str, kdsl.apps.v1.ReplicaSetConditionItem]
     ] = attr.ib(
         metadata={"yaml_name": "conditions", "mlist_key": "type"},
-        converter=kdsl.apps.v1_converters.optional_mlist_converter_DeploymentConditionItem,
+        converter=kdsl.apps.v1_converters.optional_mlist_converter_ReplicaSetConditionItem,
         default=OMIT,
     )
+    fullyLabeledReplicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "fullyLabeledReplicas"}, default=OMIT
+    )
     observedGeneration: Union[None, OmitEnum, int] = attr.ib(
         metadata={"yaml_name": "observedGeneration"}, default=OMIT
     )
     readyReplicas: Union[None, OmitEnum, int] = attr.ib(
         metadata={"yaml_name": "readyReplicas"}, default=OMIT
     )
-    replicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "replicas"}, default=OMIT
-    )
-    unavailableReplicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "unavailableReplicas"}, default=OMIT
-    )
-    updatedReplicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "updatedReplicas"}, default=OMIT
-    )
 
 
-class DeploymentStatusTypedDict(TypedDict, total=(False)):
+class ReplicaSetStatusOptionalTypedDict(TypedDict, total=(False)):
     availableReplicas: int
-    collisionCount: int
-    conditions: Mapping[str, kdsl.apps.v1.DeploymentConditionItem]
+    conditions: Mapping[str, kdsl.apps.v1.ReplicaSetConditionItem]
+    fullyLabeledReplicas: int
     observedGeneration: int
     readyReplicas: int
+
+
+class ReplicaSetStatusTypedDict(ReplicaSetStatusOptionalTypedDict, total=(True)):
     replicas: int
-    unavailableReplicas: int
-    updatedReplicas: int
 
 
-DeploymentStatusUnion = Union[DeploymentStatus, DeploymentStatusTypedDict]
+ReplicaSetStatusUnion = Union[ReplicaSetStatus, ReplicaSetStatusTypedDict]
 
 
 @attr.s(kw_only=True)
-class RollingUpdateDaemonSet(K8sObject):
-    maxUnavailable: Union[None, OmitEnum, Union[int, str]] = attr.ib(
-        metadata={"yaml_name": "maxUnavailable"}, default=OMIT
-    )
-
-
-class RollingUpdateDaemonSetTypedDict(TypedDict, total=(False)):
-    maxUnavailable: Union[int, str]
-
-
-RollingUpdateDaemonSetUnion = Union[
-    RollingUpdateDaemonSet, RollingUpdateDaemonSetTypedDict
-]
-
-
-@attr.s(kw_only=True)
-class ReplicaSet(K8sResource):
+class Deployment(K8sResource):
     apiVersion: ClassVar[str] = "apps/v1"
-    kind: ClassVar[str] = "ReplicaSet"
+    kind: ClassVar[str] = "Deployment"
     metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
         metadata={"yaml_name": "metadata"},
         converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
         default=OMIT,
     )
-    spec: Union[None, OmitEnum, kdsl.apps.v1.ReplicaSetSpec] = attr.ib(
+    spec: Union[None, OmitEnum, kdsl.apps.v1.DeploymentSpec] = attr.ib(
         metadata={"yaml_name": "spec"},
-        converter=kdsl.apps.v1_converters.optional_converter_ReplicaSetSpec,
+        converter=kdsl.apps.v1_converters.optional_converter_DeploymentSpec,
         default=OMIT,
     )
-    status: Union[None, OmitEnum, kdsl.apps.v1.ReplicaSetStatus] = attr.ib(
+    status: Union[None, OmitEnum, kdsl.apps.v1.DeploymentStatus] = attr.ib(
         metadata={"yaml_name": "status"},
-        converter=kdsl.apps.v1_converters.optional_converter_ReplicaSetStatus,
+        converter=kdsl.apps.v1_converters.optional_converter_DeploymentStatus,
         default=OMIT,
     )
 
@@ -655,12 +561,108 @@ DeploymentSpecUnion = Union[DeploymentSpec, DeploymentSpecTypedDict]
 
 
 @attr.s(kw_only=True)
-class StatefulSetUpdateStrategy(K8sObject):
-    rollingUpdate: Union[
-        None, OmitEnum, kdsl.apps.v1.RollingUpdateStatefulSetStrategy
-    ] = attr.ib(
+class DaemonSetConditionItem(K8sObject):
+    status: str = attr.ib(metadata={"yaml_name": "status"})
+    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
+    )
+    message: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "message"}, default=OMIT
+    )
+    reason: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "reason"}, default=OMIT
+    )
+
+
+class DaemonSetConditionItemOptionalTypedDict(TypedDict, total=(False)):
+    lastTransitionTime: str
+    message: str
+    reason: str
+
+
+class DaemonSetConditionItemTypedDict(
+    DaemonSetConditionItemOptionalTypedDict, total=(True)
+):
+    status: str
+
+
+DaemonSetConditionItemUnion = Union[
+    DaemonSetConditionItem, DaemonSetConditionItemTypedDict
+]
+
+
+@attr.s(kw_only=True)
+class ReplicaSetSpec(K8sObject):
+    selector: kdsl.core.v1.LabelSelector = attr.ib(
+        metadata={"yaml_name": "selector"},
+        converter=kdsl.core.v1_converters.required_converter_LabelSelector,
+    )
+    minReadySeconds: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "minReadySeconds"}, default=OMIT
+    )
+    replicas: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "replicas"}, default=OMIT
+    )
+    template: Union[None, OmitEnum, kdsl.core.v1.PodTemplateSpec] = attr.ib(
+        metadata={"yaml_name": "template"},
+        converter=kdsl.core.v1_converters.optional_converter_PodTemplateSpec,
+        default=OMIT,
+    )
+
+
+class ReplicaSetSpecOptionalTypedDict(TypedDict, total=(False)):
+    minReadySeconds: int
+    replicas: int
+    template: kdsl.core.v1.PodTemplateSpec
+
+
+class ReplicaSetSpecTypedDict(ReplicaSetSpecOptionalTypedDict, total=(True)):
+    selector: kdsl.core.v1.LabelSelector
+
+
+ReplicaSetSpecUnion = Union[ReplicaSetSpec, ReplicaSetSpecTypedDict]
+
+
+@attr.s(kw_only=True)
+class DeploymentConditionItem(K8sObject):
+    status: str = attr.ib(metadata={"yaml_name": "status"})
+    lastTransitionTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastTransitionTime"}, default=OMIT
+    )
+    lastUpdateTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastUpdateTime"}, default=OMIT
+    )
+    message: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "message"}, default=OMIT
+    )
+    reason: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "reason"}, default=OMIT
+    )
+
+
+class DeploymentConditionItemOptionalTypedDict(TypedDict, total=(False)):
+    lastTransitionTime: str
+    lastUpdateTime: str
+    message: str
+    reason: str
+
+
+class DeploymentConditionItemTypedDict(
+    DeploymentConditionItemOptionalTypedDict, total=(True)
+):
+    status: str
+
+
+DeploymentConditionItemUnion = Union[
+    DeploymentConditionItem, DeploymentConditionItemTypedDict
+]
+
+
+@attr.s(kw_only=True)
+class DaemonSetUpdateStrategy(K8sObject):
+    rollingUpdate: Union[None, OmitEnum, kdsl.apps.v1.RollingUpdateDaemonSet] = attr.ib(
         metadata={"yaml_name": "rollingUpdate"},
-        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateStatefulSetStrategy,
+        converter=kdsl.apps.v1_converters.optional_converter_RollingUpdateDaemonSet,
         default=OMIT,
     )
     type: Union[None, OmitEnum, str] = attr.ib(
@@ -668,50 +670,48 @@ class StatefulSetUpdateStrategy(K8sObject):
     )
 
 
-class StatefulSetUpdateStrategyTypedDict(TypedDict, total=(False)):
-    rollingUpdate: kdsl.apps.v1.RollingUpdateStatefulSetStrategy
+class DaemonSetUpdateStrategyTypedDict(TypedDict, total=(False)):
+    rollingUpdate: kdsl.apps.v1.RollingUpdateDaemonSet
     type: str
 
 
-StatefulSetUpdateStrategyUnion = Union[
-    StatefulSetUpdateStrategy, StatefulSetUpdateStrategyTypedDict
+DaemonSetUpdateStrategyUnion = Union[
+    DaemonSetUpdateStrategy, DaemonSetUpdateStrategyTypedDict
 ]
 
 
 @attr.s(kw_only=True)
-class ReplicaSetStatus(K8sObject):
-    replicas: int = attr.ib(metadata={"yaml_name": "replicas"})
-    availableReplicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "availableReplicas"}, default=OMIT
-    )
-    conditions: Union[
-        None, OmitEnum, Mapping[str, kdsl.apps.v1.ReplicaSetConditionItem]
-    ] = attr.ib(
-        metadata={"yaml_name": "conditions", "mlist_key": "type"},
-        converter=kdsl.apps.v1_converters.optional_mlist_converter_ReplicaSetConditionItem,
+class DaemonSet(K8sResource):
+    apiVersion: ClassVar[str] = "apps/v1"
+    kind: ClassVar[str] = "DaemonSet"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
         default=OMIT,
     )
-    fullyLabeledReplicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "fullyLabeledReplicas"}, default=OMIT
+    spec: Union[None, OmitEnum, kdsl.apps.v1.DaemonSetSpec] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.apps.v1_converters.optional_converter_DaemonSetSpec,
+        default=OMIT,
     )
-    observedGeneration: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "observedGeneration"}, default=OMIT
-    )
-    readyReplicas: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "readyReplicas"}, default=OMIT
+    status: Union[None, OmitEnum, kdsl.apps.v1.DaemonSetStatus] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.apps.v1_converters.optional_converter_DaemonSetStatus,
+        default=OMIT,
     )
 
 
-class ReplicaSetStatusOptionalTypedDict(TypedDict, total=(False)):
-    availableReplicas: int
-    conditions: Mapping[str, kdsl.apps.v1.ReplicaSetConditionItem]
-    fullyLabeledReplicas: int
-    observedGeneration: int
-    readyReplicas: int
+@attr.s(kw_only=True)
+class RollingUpdateDaemonSet(K8sObject):
+    maxUnavailable: Union[None, OmitEnum, Union[int, str]] = attr.ib(
+        metadata={"yaml_name": "maxUnavailable"}, default=OMIT
+    )
 
 
-class ReplicaSetStatusTypedDict(ReplicaSetStatusOptionalTypedDict, total=(True)):
-    replicas: int
+class RollingUpdateDaemonSetTypedDict(TypedDict, total=(False)):
+    maxUnavailable: Union[int, str]
 
 
-ReplicaSetStatusUnion = Union[ReplicaSetStatus, ReplicaSetStatusTypedDict]
+RollingUpdateDaemonSetUnion = Union[
+    RollingUpdateDaemonSet, RollingUpdateDaemonSetTypedDict
+]
