@@ -1,37 +1,11 @@
 from __future__ import annotations
+import kdsl.core.v1_converters
 import kdsl.core.v1
+import kdsl.authentication.v1beta1_converters
 import attr
 import kdsl.authentication.v1beta1
-import kdsl.authentication.v1beta1_converters
-import kdsl.core.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
-
-
-@attr.s(kw_only=True)
-class UserInfo(K8sObject):
-    extra: Union[None, OmitEnum, Mapping[str, Sequence[str]]] = attr.ib(
-        metadata={"yaml_name": "extra"}, default=OMIT
-    )
-    groups: Union[None, OmitEnum, Sequence[str]] = attr.ib(
-        metadata={"yaml_name": "groups"}, default=OMIT
-    )
-    uid: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "uid"}, default=OMIT
-    )
-    username: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "username"}, default=OMIT
-    )
-
-
-class UserInfoTypedDict(TypedDict, total=(False)):
-    extra: Mapping[str, Sequence[str]]
-    groups: Sequence[str]
-    uid: str
-    username: str
-
-
-UserInfoUnion = Union[UserInfo, UserInfoTypedDict]
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -62,6 +36,24 @@ class TokenReviewStatusTypedDict(TypedDict, total=(False)):
 TokenReviewStatusUnion = Union[TokenReviewStatus, TokenReviewStatusTypedDict]
 
 
+@attr.s(kw_only=True)
+class TokenReviewSpec(K8sObject):
+    audiences: Union[None, OmitEnum, Sequence[str]] = attr.ib(
+        metadata={"yaml_name": "audiences"}, default=OMIT
+    )
+    token: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "token"}, default=OMIT
+    )
+
+
+class TokenReviewSpecTypedDict(TypedDict, total=(False)):
+    audiences: Sequence[str]
+    token: str
+
+
+TokenReviewSpecUnion = Union[TokenReviewSpec, TokenReviewSpecTypedDict]
+
+
 @attr.s(kw_only=True)
 class TokenReview(K8sResource):
     apiVersion: ClassVar[str] = "authentication.k8s.io/v1beta1"
@@ -85,18 +77,26 @@ class TokenReview(K8sResource):
 
 
 @attr.s(kw_only=True)
-class TokenReviewSpec(K8sObject):
-    audiences: Union[None, OmitEnum, Sequence[str]] = attr.ib(
-        metadata={"yaml_name": "audiences"}, default=OMIT
+class UserInfo(K8sObject):
+    extra: Union[None, OmitEnum, Mapping[str, Sequence[str]]] = attr.ib(
+        metadata={"yaml_name": "extra"}, default=OMIT
     )
-    token: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "token"}, default=OMIT
+    groups: Union[None, OmitEnum, Sequence[str]] = attr.ib(
+        metadata={"yaml_name": "groups"}, default=OMIT
+    )
+    uid: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "uid"}, default=OMIT
+    )
+    username: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "username"}, default=OMIT
     )
 
 
-class TokenReviewSpecTypedDict(TypedDict, total=(False)):
-    audiences: Sequence[str]
-    token: str
+class UserInfoTypedDict(TypedDict, total=(False)):
+    extra: Mapping[str, Sequence[str]]
+    groups: Sequence[str]
+    uid: str
+    username: str
 
 
-TokenReviewSpecUnion = Union[TokenReviewSpec, TokenReviewSpecTypedDict]
+UserInfoUnion = Union[UserInfo, UserInfoTypedDict]
