@@ -1,36 +1,11 @@
 from __future__ import annotations
-import kdsl.autoscaling.v1
-import attr
-import kdsl.core.v1
 import kdsl.core.v1_converters
+import kdsl.core.v1
 import kdsl.autoscaling.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Sequence, Optional, TypedDict, Any
-
-
-@attr.s(kw_only=True)
-class HorizontalPodAutoscaler(K8sResource):
-    apiVersion: ClassVar[str] = "autoscaling/v1"
-    kind: ClassVar[str] = "HorizontalPodAutoscaler"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[
-        None, OmitEnum, kdsl.autoscaling.v1.HorizontalPodAutoscalerSpec
-    ] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.autoscaling.v1_converters.optional_converter_HorizontalPodAutoscalerSpec,
-        default=OMIT,
-    )
-    status: Union[
-        None, OmitEnum, kdsl.autoscaling.v1.HorizontalPodAutoscalerStatus
-    ] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.autoscaling.v1_converters.optional_converter_HorizontalPodAutoscalerStatus,
-        default=OMIT,
-    )
+import attr
+import kdsl.autoscaling.v1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -58,6 +33,31 @@ CrossVersionObjectReferenceUnion = Union[
 ]
 
 
+@attr.s(kw_only=True)
+class HorizontalPodAutoscaler(K8sResource):
+    apiVersion: ClassVar[str] = "autoscaling/v1"
+    kind: ClassVar[str] = "HorizontalPodAutoscaler"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    spec: Union[
+        None, OmitEnum, kdsl.autoscaling.v1.HorizontalPodAutoscalerSpec
+    ] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.autoscaling.v1_converters.optional_converter_HorizontalPodAutoscalerSpec,
+        default=OMIT,
+    )
+    status: Union[
+        None, OmitEnum, kdsl.autoscaling.v1.HorizontalPodAutoscalerStatus
+    ] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.autoscaling.v1_converters.optional_converter_HorizontalPodAutoscalerStatus,
+        default=OMIT,
+    )
+
+
 @attr.s(kw_only=True)
 class HorizontalPodAutoscalerStatus(K8sObject):
     currentReplicas: int = attr.ib(metadata={"yaml_name": "currentReplicas"})
