@@ -1,13 +1,13 @@
 from __future__ import annotations
-import kdsl.batch.v1_converters
-import kdsl.core.v1
-import kdsl.batch.v1
 import kdsl.core.v1_converters
-import kdsl.batch.v1beta1
-import attr
 import kdsl.batch.v1beta1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Sequence, Optional, TypedDict, Any
+import attr
+import kdsl.batch.v1_converters
+import kdsl.batch.v1
+import kdsl.core.v1
+import kdsl.batch.v1beta1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -32,26 +32,6 @@ class JobTemplateSpecTypedDict(TypedDict, total=(False)):
 JobTemplateSpecUnion = Union[JobTemplateSpec, JobTemplateSpecTypedDict]
 
 
-@attr.s(kw_only=True)
-class CronJobStatus(K8sObject):
-    active: Union[None, OmitEnum, Sequence[kdsl.core.v1.ObjectReference]] = attr.ib(
-        metadata={"yaml_name": "active"},
-        converter=kdsl.core.v1_converters.optional_list_converter_ObjectReference,
-        default=OMIT,
-    )
-    lastScheduleTime: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "lastScheduleTime"}, default=OMIT
-    )
-
-
-class CronJobStatusTypedDict(TypedDict, total=(False)):
-    active: Sequence[kdsl.core.v1.ObjectReference]
-    lastScheduleTime: str
-
-
-CronJobStatusUnion = Union[CronJobStatus, CronJobStatusTypedDict]
-
-
 @attr.s(kw_only=True)
 class CronJob(K8sResource):
     apiVersion: ClassVar[str] = "batch/v1beta1"
@@ -73,6 +53,26 @@ class CronJob(K8sResource):
     )
 
 
+@attr.s(kw_only=True)
+class CronJobStatus(K8sObject):
+    active: Union[None, OmitEnum, Sequence[kdsl.core.v1.ObjectReference]] = attr.ib(
+        metadata={"yaml_name": "active"},
+        converter=kdsl.core.v1_converters.optional_list_converter_ObjectReference,
+        default=OMIT,
+    )
+    lastScheduleTime: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "lastScheduleTime"}, default=OMIT
+    )
+
+
+class CronJobStatusTypedDict(TypedDict, total=(False)):
+    active: Sequence[kdsl.core.v1.ObjectReference]
+    lastScheduleTime: str
+
+
+CronJobStatusUnion = Union[CronJobStatus, CronJobStatusTypedDict]
+
+
 @attr.s(kw_only=True)
 class CronJobSpec(K8sObject):
     jobTemplate: kdsl.batch.v1beta1.JobTemplateSpec = attr.ib(
