@@ -1,11 +1,36 @@
 from __future__ import annotations
-import attr
-import kdsl.core.v1
-import kdsl.certificates.v1beta1_converters
 import kdsl.core.v1_converters
 import kdsl.certificates.v1beta1
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+import kdsl.certificates.v1beta1_converters
+import kdsl.core.v1
+import attr
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
+
+
+@attr.s(kw_only=True)
+class CertificateSigningRequest(K8sResource):
+    apiVersion: ClassVar[str] = "certificates.k8s.io/v1beta1"
+    kind: ClassVar[str] = "CertificateSigningRequest"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    spec: Union[
+        None, OmitEnum, kdsl.certificates.v1beta1.CertificateSigningRequestSpec
+    ] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.certificates.v1beta1_converters.optional_converter_CertificateSigningRequestSpec,
+        default=OMIT,
+    )
+    status: Union[
+        None, OmitEnum, kdsl.certificates.v1beta1.CertificateSigningRequestStatus
+    ] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.certificates.v1beta1_converters.optional_converter_CertificateSigningRequestStatus,
+        default=OMIT,
+    )
 
 
 @attr.s(kw_only=True)
@@ -47,31 +72,6 @@ CertificateSigningRequestSpecUnion = Union[
 ]
 
 
-@attr.s(kw_only=True)
-class CertificateSigningRequest(K8sResource):
-    apiVersion: ClassVar[str] = "certificates.k8s.io/v1beta1"
-    kind: ClassVar[str] = "CertificateSigningRequest"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[
-        None, OmitEnum, kdsl.certificates.v1beta1.CertificateSigningRequestSpec
-    ] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.certificates.v1beta1_converters.optional_converter_CertificateSigningRequestSpec,
-        default=OMIT,
-    )
-    status: Union[
-        None, OmitEnum, kdsl.certificates.v1beta1.CertificateSigningRequestStatus
-    ] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.certificates.v1beta1_converters.optional_converter_CertificateSigningRequestStatus,
-        default=OMIT,
-    )
-
-
 @attr.s(kw_only=True)
 class CertificateSigningRequestCondition(K8sObject):
     type: str = attr.ib(metadata={"yaml_name": "type"})
