@@ -1,6 +1,6 @@
 from __future__ import annotations
 from kdsl.bases import OMIT, OmitEnum
-from typing import Literal, Union
+from typing import Union, Literal
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
