@@ -1,11 +1,11 @@
 from __future__ import annotations
-import attr
-import kdsl.core.v1
 import kdsl.core.v1_converters
-import kdsl.coordination.v1beta1
+import kdsl.core.v1
+import attr
 import kdsl.coordination.v1beta1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Sequence, Optional, TypedDict, Any
+import kdsl.coordination.v1beta1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
