@@ -1,11 +1,11 @@
 from __future__ import annotations
-import kdsl.core.v1
-import attr
 import kdsl.core.v1_converters
+import attr
 import kdsl.discovery.v1beta1
 import kdsl.discovery.v1beta1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+import kdsl.core.v1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -46,28 +46,19 @@ EndpointUnion = Union[Endpoint, EndpointTypedDict]
 
 
 @attr.s(kw_only=True)
-class EndpointSlice(K8sResource):
-    apiVersion: ClassVar[str] = "discovery.k8s.io/v1beta1"
-    kind: ClassVar[str] = "EndpointSlice"
-    addressType: str = attr.ib(metadata={"yaml_name": "addressType"})
-    endpoints: Sequence[kdsl.discovery.v1beta1.Endpoint] = attr.ib(
-        metadata={"yaml_name": "endpoints"},
-        converter=kdsl.discovery.v1beta1_converters.required_list_converter_Endpoint,
-    )
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    ports: Union[
-        None, OmitEnum, Sequence[kdsl.discovery.v1beta1.EndpointPort]
-    ] = attr.ib(
-        metadata={"yaml_name": "ports"},
-        converter=kdsl.discovery.v1beta1_converters.optional_list_converter_EndpointPort,
-        default=OMIT,
+class EndpointConditions(K8sObject):
+    ready: Union[None, OmitEnum, bool] = attr.ib(
+        metadata={"yaml_name": "ready"}, default=OMIT
     )
 
 
+class EndpointConditionsTypedDict(TypedDict, total=(False)):
+    ready: bool
+
+
+EndpointConditionsUnion = Union[EndpointConditions, EndpointConditionsTypedDict]
+
+
 @attr.s(kw_only=True)
 class EndpointPort(K8sObject):
     appProtocol: Union[None, OmitEnum, str] = attr.ib(
@@ -95,14 +86,23 @@ EndpointPortUnion = Union[EndpointPort, EndpointPortTypedDict]
 
 
 @attr.s(kw_only=True)
-class EndpointConditions(K8sObject):
-    ready: Union[None, OmitEnum, bool] = attr.ib(
-        metadata={"yaml_name": "ready"}, default=OMIT
+class EndpointSlice(K8sResource):
+    apiVersion: ClassVar[str] = "discovery.k8s.io/v1beta1"
+    kind: ClassVar[str] = "EndpointSlice"
+    addressType: str = attr.ib(metadata={"yaml_name": "addressType"})
+    endpoints: Sequence[kdsl.discovery.v1beta1.Endpoint] = attr.ib(
+        metadata={"yaml_name": "endpoints"},
+        converter=kdsl.discovery.v1beta1_converters.required_list_converter_Endpoint,
+    )
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    ports: Union[
+        None, OmitEnum, Sequence[kdsl.discovery.v1beta1.EndpointPort]
+    ] = attr.ib(
+        metadata={"yaml_name": "ports"},
+        converter=kdsl.discovery.v1beta1_converters.optional_list_converter_EndpointPort,
+        default=OMIT,
     )
-
-
-class EndpointConditionsTypedDict(TypedDict, total=(False)):
-    ready: bool
-
-
-EndpointConditionsUnion = Union[EndpointConditions, EndpointConditionsTypedDict]
