@@ -1,11 +1,27 @@
 from __future__ import annotations
-import kdsl.events.v1beta1_converters
-import attr
-import kdsl.core.v1
-import kdsl.events.v1beta1
 import kdsl.core.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+import kdsl.core.v1
+import attr
+import kdsl.events.v1beta1_converters
+import kdsl.events.v1beta1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
+
+
+@attr.s(kw_only=True)
+class EventSeries(K8sObject):
+    count: int = attr.ib(metadata={"yaml_name": "count"})
+    lastObservedTime: str = attr.ib(metadata={"yaml_name": "lastObservedTime"})
+    state: str = attr.ib(metadata={"yaml_name": "state"})
+
+
+class EventSeriesTypedDict(TypedDict, total=(True)):
+    count: int
+    lastObservedTime: str
+    state: str
+
+
+EventSeriesUnion = Union[EventSeries, EventSeriesTypedDict]
 
 
 @attr.s(kw_only=True)
@@ -65,19 +81,3 @@ class Event(K8sResource):
     type: Union[None, OmitEnum, str] = attr.ib(
         metadata={"yaml_name": "type"}, default=OMIT
     )
-
-
-@attr.s(kw_only=True)
-class EventSeries(K8sObject):
-    count: int = attr.ib(metadata={"yaml_name": "count"})
-    lastObservedTime: str = attr.ib(metadata={"yaml_name": "lastObservedTime"})
-    state: str = attr.ib(metadata={"yaml_name": "state"})
-
-
-class EventSeriesTypedDict(TypedDict, total=(True)):
-    count: int
-    lastObservedTime: str
-    state: str
-
-
-EventSeriesUnion = Union[EventSeries, EventSeriesTypedDict]
