@@ -1,11 +1,11 @@
 from __future__ import annotations
-import kdsl.core.v1
+import kdsl.core.v1_converters
 import attr
 import kdsl.networking.v1
 import kdsl.networking.v1_converters
-import kdsl.core.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+import kdsl.core.v1
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -46,22 +46,6 @@ class NetworkPolicySpecTypedDict(NetworkPolicySpecOptionalTypedDict, total=(True
 NetworkPolicySpecUnion = Union[NetworkPolicySpec, NetworkPolicySpecTypedDict]
 
 
-@attr.s(kw_only=True)
-class NetworkPolicy(K8sResource):
-    apiVersion: ClassVar[str] = "networking.k8s.io/v1"
-    kind: ClassVar[str] = "NetworkPolicy"
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    spec: Union[None, OmitEnum, kdsl.networking.v1.NetworkPolicySpec] = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.networking.v1_converters.optional_converter_NetworkPolicySpec,
-        default=OMIT,
-    )
-
-
 @attr.s(kw_only=True)
 class NetworkPolicyIngressRule(K8sObject):
     from_: Union[
@@ -90,6 +74,59 @@ NetworkPolicyIngressRuleUnion = Union[
 ]
 
 
+@attr.s(kw_only=True)
+class NetworkPolicy(K8sResource):
+    apiVersion: ClassVar[str] = "networking.k8s.io/v1"
+    kind: ClassVar[str] = "NetworkPolicy"
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    spec: Union[None, OmitEnum, kdsl.networking.v1.NetworkPolicySpec] = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.networking.v1_converters.optional_converter_NetworkPolicySpec,
+        default=OMIT,
+    )
+
+
+@attr.s(kw_only=True)
+class NetworkPolicyPort(K8sObject):
+    port: Union[None, OmitEnum, Union[int, str]] = attr.ib(
+        metadata={"yaml_name": "port"}, default=OMIT
+    )
+    protocol: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "protocol"}, default=OMIT
+    )
+
+
+class NetworkPolicyPortTypedDict(TypedDict, total=(False)):
+    port: Union[int, str]
+    protocol: str
+
+
+NetworkPolicyPortUnion = Union[NetworkPolicyPort, NetworkPolicyPortTypedDict]
+
+
+@attr.s(kw_only=True)
+class IPBlock(K8sObject):
+    cidr: str = attr.ib(metadata={"yaml_name": "cidr"})
+    except_: Union[None, OmitEnum, Sequence[str]] = attr.ib(
+        metadata={"yaml_name": "except"}, default=OMIT
+    )
+
+
+class IPBlockOptionalTypedDict(TypedDict, total=(False)):
+    except_: Sequence[str]
+
+
+class IPBlockTypedDict(IPBlockOptionalTypedDict, total=(True)):
+    cidr: str
+
+
+IPBlockUnion = Union[IPBlock, IPBlockTypedDict]
+
+
 @attr.s(kw_only=True)
 class NetworkPolicyPeer(K8sObject):
     ipBlock: Union[None, OmitEnum, kdsl.networking.v1.IPBlock] = attr.ib(
@@ -118,25 +155,6 @@ class NetworkPolicyPeerTypedDict(TypedDict, total=(False)):
 NetworkPolicyPeerUnion = Union[NetworkPolicyPeer, NetworkPolicyPeerTypedDict]
 
 
-@attr.s(kw_only=True)
-class IPBlock(K8sObject):
-    cidr: str = attr.ib(metadata={"yaml_name": "cidr"})
-    except_: Union[None, OmitEnum, Sequence[str]] = attr.ib(
-        metadata={"yaml_name": "except"}, default=OMIT
-    )
-
-
-class IPBlockOptionalTypedDict(TypedDict, total=(False)):
-    except_: Sequence[str]
-
-
-class IPBlockTypedDict(IPBlockOptionalTypedDict, total=(True)):
-    cidr: str
-
-
-IPBlockUnion = Union[IPBlock, IPBlockTypedDict]
-
-
 @attr.s(kw_only=True)
 class NetworkPolicyEgressRule(K8sObject):
     ports: Union[
@@ -161,21 +179,3 @@ class NetworkPolicyEgressRuleTypedDict(TypedDict, total=(False)):
 NetworkPolicyEgressRuleUnion = Union[
     NetworkPolicyEgressRule, NetworkPolicyEgressRuleTypedDict
 ]
-
-
-@attr.s(kw_only=True)
-class NetworkPolicyPort(K8sObject):
-    port: Union[None, OmitEnum, Union[int, str]] = attr.ib(
-        metadata={"yaml_name": "port"}, default=OMIT
-    )
-    protocol: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "protocol"}, default=OMIT
-    )
-
-
-class NetworkPolicyPortTypedDict(TypedDict, total=(False)):
-    port: Union[int, str]
-    protocol: str
-
-
-NetworkPolicyPortUnion = Union[NetworkPolicyPort, NetworkPolicyPortTypedDict]
