@@ -1,25 +1,11 @@
 from __future__ import annotations
-import kdsl.node.v1beta1_converters
-import attr
-import kdsl.core.v1
 import kdsl.core.v1_converters
+import kdsl.node.v1beta1_converters
+import kdsl.core.v1
+import attr
 import kdsl.node.v1beta1
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
-
-
-@attr.s(kw_only=True)
-class Overhead(K8sObject):
-    podFixed: Union[None, OmitEnum, Mapping[str, str]] = attr.ib(
-        metadata={"yaml_name": "podFixed"}, default=OMIT
-    )
-
-
-class OverheadTypedDict(TypedDict, total=(False)):
-    podFixed: Mapping[str, str]
-
-
-OverheadUnion = Union[Overhead, OverheadTypedDict]
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
@@ -62,3 +48,17 @@ class SchedulingTypedDict(TypedDict, total=(False)):
 
 
 SchedulingUnion = Union[Scheduling, SchedulingTypedDict]
+
+
+@attr.s(kw_only=True)
+class Overhead(K8sObject):
+    podFixed: Union[None, OmitEnum, Mapping[str, str]] = attr.ib(
+        metadata={"yaml_name": "podFixed"}, default=OMIT
+    )
+
+
+class OverheadTypedDict(TypedDict, total=(False)):
+    podFixed: Mapping[str, str]
+
+
+OverheadUnion = Union[Overhead, OverheadTypedDict]
