@@ -1,12 +1,20 @@
 from __future__ import annotations
 from kdsl.bases import OMIT, OmitEnum
-from typing import Literal, Union
+from typing import Union, Literal
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     import kdsl.node.v1beta1
 
 
+def optional_converter_Overhead(
+    value: Union[kdsl.node.v1beta1.OverheadUnion, OmitEnum, None]
+) -> Union[kdsl.node.v1beta1.Overhead, OmitEnum, None]:
+    import kdsl.node.v1beta1
+
+    return kdsl.node.v1beta1.Overhead(**value) if isinstance(value, dict) else value
+
+
 def optional_converter_Scheduling(
     value: Union[kdsl.node.v1beta1.SchedulingUnion, OmitEnum, None]
 ) -> Union[kdsl.node.v1beta1.Scheduling, OmitEnum, None]:
@@ -29,11 +37,3 @@ def required_converter_Scheduling(
     import kdsl.node.v1beta1
 
     return kdsl.node.v1beta1.Scheduling(**value) if isinstance(value, dict) else value
-
-
-def optional_converter_Overhead(
-    value: Union[kdsl.node.v1beta1.OverheadUnion, OmitEnum, None]
-) -> Union[kdsl.node.v1beta1.Overhead, OmitEnum, None]:
-    import kdsl.node.v1beta1
-
-    return kdsl.node.v1beta1.Overhead(**value) if isinstance(value, dict) else value
