@@ -1,9 +1,9 @@
 from __future__ import annotations
-import kdsl.core.v1
 import kdsl.core.v1_converters
 import attr
-from kdsl.bases import K8sObject, OmitEnum, K8sResource, OMIT
-from typing import ClassVar, Mapping, Sequence, Optional, TypedDict, Any, Union
+import kdsl.core.v1
+from kdsl.bases import OMIT, K8sObject, K8sResource, OmitEnum
+from typing import Union, TypedDict, Sequence, ClassVar, Any, Mapping, Optional
 
 
 @attr.s(kw_only=True)
