@@ -1,30 +1,61 @@
 from __future__ import annotations
+import kdsl.core.v1_converters
 import kdsl.core.v1
+import kdsl.storage.v1_converters
 import attr
 import kdsl.storage.v1
-import kdsl.core.v1_converters
-import kdsl.storage.v1_converters
-from kdsl.bases import K8sObject, K8sResource, OMIT, OmitEnum
-from typing import Mapping, Union, ClassVar, Optional, TypedDict, Any, Sequence
+from kdsl.bases import K8sObject, OMIT, K8sResource, OmitEnum
+from typing import Union, Optional, TypedDict, Sequence, ClassVar, Any, Mapping
 
 
 @attr.s(kw_only=True)
-class VolumeAttachmentSpec(K8sObject):
-    attacher: str = attr.ib(metadata={"yaml_name": "attacher"})
-    nodeName: str = attr.ib(metadata={"yaml_name": "nodeName"})
-    source: kdsl.storage.v1.VolumeAttachmentSource = attr.ib(
-        metadata={"yaml_name": "source"},
-        converter=kdsl.storage.v1_converters.required_converter_VolumeAttachmentSource,
+class CSINodeSpec(K8sObject):
+    drivers: Mapping[str, kdsl.storage.v1.CSINodeDriverItem] = attr.ib(
+        metadata={"yaml_name": "drivers", "mlist_key": "name"},
+        converter=kdsl.storage.v1_converters.required_mlist_converter_CSINodeDriverItem,
     )
 
 
-class VolumeAttachmentSpecTypedDict(TypedDict, total=(True)):
-    attacher: str
-    nodeName: str
-    source: kdsl.storage.v1.VolumeAttachmentSource
+class CSINodeSpecTypedDict(TypedDict, total=(True)):
+    drivers: Mapping[str, kdsl.storage.v1.CSINodeDriverItem]
 
 
-VolumeAttachmentSpecUnion = Union[VolumeAttachmentSpec, VolumeAttachmentSpecTypedDict]
+CSINodeSpecUnion = Union[CSINodeSpec, CSINodeSpecTypedDict]
+
+
+@attr.s(kw_only=True)
+class VolumeAttachment(K8sResource):
+    apiVersion: ClassVar[str] = "storage.k8s.io/v1"
+    kind: ClassVar[str] = "VolumeAttachment"
+    spec: kdsl.storage.v1.VolumeAttachmentSpec = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.storage.v1_converters.required_converter_VolumeAttachmentSpec,
+    )
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
+    status: Union[None, OmitEnum, kdsl.storage.v1.VolumeAttachmentStatus] = attr.ib(
+        metadata={"yaml_name": "status"},
+        converter=kdsl.storage.v1_converters.optional_converter_VolumeAttachmentStatus,
+        default=OMIT,
+    )
+
+
+@attr.s(kw_only=True)
+class CSINode(K8sResource):
+    apiVersion: ClassVar[str] = "storage.k8s.io/v1"
+    kind: ClassVar[str] = "CSINode"
+    spec: kdsl.storage.v1.CSINodeSpec = attr.ib(
+        metadata={"yaml_name": "spec"},
+        converter=kdsl.storage.v1_converters.required_converter_CSINodeSpec,
+    )
+    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
+        metadata={"yaml_name": "metadata"},
+        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
+        default=OMIT,
+    )
 
 
 @attr.s(kw_only=True)
@@ -80,6 +111,49 @@ class VolumeErrorTypedDict(TypedDict, total=(False)):
 VolumeErrorUnion = Union[VolumeError, VolumeErrorTypedDict]
 
 
+@attr.s(kw_only=True)
+class VolumeAttachmentSource(K8sObject):
+    inlineVolumeSpec: Union[
+        None, OmitEnum, kdsl.core.v1.PersistentVolumeSpec
+    ] = attr.ib(
+        metadata={"yaml_name": "inlineVolumeSpec"},
+        converter=kdsl.core.v1_converters.optional_converter_PersistentVolumeSpec,
+        default=OMIT,
+    )
+    persistentVolumeName: Union[None, OmitEnum, str] = attr.ib(
+        metadata={"yaml_name": "persistentVolumeName"}, default=OMIT
+    )
+
+
+class VolumeAttachmentSourceTypedDict(TypedDict, total=(False)):
+    inlineVolumeSpec: kdsl.core.v1.PersistentVolumeSpec
+    persistentVolumeName: str
+
+
+VolumeAttachmentSourceUnion = Union[
+    VolumeAttachmentSource, VolumeAttachmentSourceTypedDict
+]
+
+
+@attr.s(kw_only=True)
+class VolumeAttachmentSpec(K8sObject):
+    attacher: str = attr.ib(metadata={"yaml_name": "attacher"})
+    nodeName: str = attr.ib(metadata={"yaml_name": "nodeName"})
+    source: kdsl.storage.v1.VolumeAttachmentSource = attr.ib(
+        metadata={"yaml_name": "source"},
+        converter=kdsl.storage.v1_converters.required_converter_VolumeAttachmentSource,
+    )
+
+
+class VolumeAttachmentSpecTypedDict(TypedDict, total=(True)):
+    attacher: str
+    nodeName: str
+    source: kdsl.storage.v1.VolumeAttachmentSource
+
+
+VolumeAttachmentSpecUnion = Union[VolumeAttachmentSpec, VolumeAttachmentSpecTypedDict]
+
+
 @attr.s(kw_only=True)
 class CSINodeDriverItem(K8sObject):
     nodeID: str = attr.ib(metadata={"yaml_name": "nodeID"})
@@ -106,47 +180,17 @@ CSINodeDriverItemUnion = Union[CSINodeDriverItem, CSINodeDriverItemTypedDict]
 
 
 @attr.s(kw_only=True)
-class VolumeAttachment(K8sResource):
-    apiVersion: ClassVar[str] = "storage.k8s.io/v1"
-    kind: ClassVar[str] = "VolumeAttachment"
-    spec: kdsl.storage.v1.VolumeAttachmentSpec = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.storage.v1_converters.required_converter_VolumeAttachmentSpec,
-    )
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-    status: Union[None, OmitEnum, kdsl.storage.v1.VolumeAttachmentStatus] = attr.ib(
-        metadata={"yaml_name": "status"},
-        converter=kdsl.storage.v1_converters.optional_converter_VolumeAttachmentStatus,
-        default=OMIT,
+class VolumeNodeResources(K8sObject):
+    count: Union[None, OmitEnum, int] = attr.ib(
+        metadata={"yaml_name": "count"}, default=OMIT
     )
 
 
-@attr.s(kw_only=True)
-class VolumeAttachmentSource(K8sObject):
-    inlineVolumeSpec: Union[
-        None, OmitEnum, kdsl.core.v1.PersistentVolumeSpec
-    ] = attr.ib(
-        metadata={"yaml_name": "inlineVolumeSpec"},
-        converter=kdsl.core.v1_converters.optional_converter_PersistentVolumeSpec,
-        default=OMIT,
-    )
-    persistentVolumeName: Union[None, OmitEnum, str] = attr.ib(
-        metadata={"yaml_name": "persistentVolumeName"}, default=OMIT
-    )
+class VolumeNodeResourcesTypedDict(TypedDict, total=(False)):
+    count: int
 
 
-class VolumeAttachmentSourceTypedDict(TypedDict, total=(False)):
-    inlineVolumeSpec: kdsl.core.v1.PersistentVolumeSpec
-    persistentVolumeName: str
-
-
-VolumeAttachmentSourceUnion = Union[
-    VolumeAttachmentSource, VolumeAttachmentSourceTypedDict
-]
+VolumeNodeResourcesUnion = Union[VolumeNodeResources, VolumeNodeResourcesTypedDict]
 
 
 @attr.s(kw_only=True)
@@ -181,47 +225,3 @@ class StorageClass(K8sResource):
     volumeBindingMode: Union[None, OmitEnum, str] = attr.ib(
         metadata={"yaml_name": "volumeBindingMode"}, default=OMIT
     )
-
-
-@attr.s(kw_only=True)
-class CSINodeSpec(K8sObject):
-    drivers: Mapping[str, kdsl.storage.v1.CSINodeDriverItem] = attr.ib(
-        metadata={"yaml_name": "drivers", "mlist_key": "name"},
-        converter=kdsl.storage.v1_converters.required_mlist_converter_CSINodeDriverItem,
-    )
-
-
-class CSINodeSpecTypedDict(TypedDict, total=(True)):
-    drivers: Mapping[str, kdsl.storage.v1.CSINodeDriverItem]
-
-
-CSINodeSpecUnion = Union[CSINodeSpec, CSINodeSpecTypedDict]
-
-
-@attr.s(kw_only=True)
-class CSINode(K8sResource):
-    apiVersion: ClassVar[str] = "storage.k8s.io/v1"
-    kind: ClassVar[str] = "CSINode"
-    spec: kdsl.storage.v1.CSINodeSpec = attr.ib(
-        metadata={"yaml_name": "spec"},
-        converter=kdsl.storage.v1_converters.required_converter_CSINodeSpec,
-    )
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(
-        metadata={"yaml_name": "metadata"},
-        converter=kdsl.core.v1_converters.optional_converter_ObjectMeta,
-        default=OMIT,
-    )
-
-
-@attr.s(kw_only=True)
-class VolumeNodeResources(K8sObject):
-    count: Union[None, OmitEnum, int] = attr.ib(
-        metadata={"yaml_name": "count"}, default=OMIT
-    )
-
-
-class VolumeNodeResourcesTypedDict(TypedDict, total=(False)):
-    count: int
-
-
-VolumeNodeResourcesUnion = Union[VolumeNodeResources, VolumeNodeResourcesTypedDict]
